@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 11932 2020-02-18 17:50:41Z Lavender $
+# $Id: __init__.py 11982 2020-03-19 11:39:46Z Lavender $
 #
 # Copyright (c) 2018 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $ (last)
-# $Date: 2020-02-19 02:50:41 +0900 (週三, 19 二月 2020) $
-# $Revision: 11932 $
+# $Date: 2020-03-19 20:39:46 +0900 (週四, 19 三月 2020) $
+# $Revision: 11982 $
 
 import os
 import sys
@@ -625,6 +625,8 @@ def attachShopURLs(settings, urlpatterns):
             name='updateBonus'),
         url(r'^shop/basket/bonus',
             views.useBonus, name="useBonus"),
+        url(r'^shop/customer/bonus',
+            views.CustomerBonusListView.as_view(), name="customerBonusList"),
         url(r'^shop/send_confirm_code/$', views.sendConfirmCode, 
             name='sendConfirmCode'),
     )
